function  RTR()
%% GUI designed by Ashish Tanwer to Capture Arial Videos through TV-Tuner
% Card for "DRDO Golden Jubilee Student Competition" Contest
%Create a video input object.
clear;

vid = videoinput('winvideo');
set(vid,'ReturnedColorSpace','rgb');
%% Create a figure window. 
hFig = figure('Toolbar','none','Menubar', 'none','NumberTitle','Off',...
    'Name','Video Capture GUI','DeleteFcn',{@deletefig_callback});
axis off;
%% Set up the push buttons
uicontrol('String', 'Start Preview','Callback',{@startpreview_callback},...
    'Units','normalized','Position',[.01 .01 0.15 .06],'Parent',hFig);

uicontrol('String', 'Stop Preview','Callback',{@stoppreview_callback},...
    'Units','normalized','Position',[.16 .01 .15 .06],'Parent',hFig);

uicontrol('String', 'Snapshot','Callback', {@snapshot_callback},...
    'Units','normalized','Position',[.32 .01 .15 .06],'Parent',hFig);

tgl = uicontrol('String','Save Images','Callback',{@saveimages_callback},...
    'Units','normalized','Position',[.48 .01 .15 .06],'Parent',hFig);

uicontrol('String','Start Capture','Callback', {@startcapture_callback},...
    'Units','normalized','Position',[.64 .01 .15 .06],'Parent',hFig);

uicontrol('String', 'Stop Capture','Callback', {@stopcapture_callback},...
    'Units','normalized','Position',[.8 .01 .15 .06],'Parent',hFig);
%% Initialization tasks
vidRes = get(vid, 'VideoResolution');
imWidth = vidRes(1);
imHeight = vidRes(2);
nBands = get(vid, 'NumberOfBands');
hImage = image( zeros(imHeight, imWidth, nBands) );

figSize = get(hFig,'Position');
figWidth = figSize(3);
figHeight = figSize(4);

set(gca,'unit','pixels', 'position',[ ((figWidth - imWidth)/2) ((figHeight - imHeight)/2) imWidth imHeight ]);
%% Set up the update preview window function.
setappdata(hImage,'UpdatePreviewWindowFcn',@mypreview_fcn);

preview(vid, hImage);
%% Utility functions for MYGUI
    function mypreview_fcn(obj,event,himage)
    % Example update preview window function.

    % Get timestamp for frame.
    tstampstr = event.Timestamp;

    % Get handle to text label uicontrol.
    ht = getappdata(himage,'HandleToTimestampLabel');

    % Set the value of the text label.
    set(ht,'String',tstampstr);

    % Display image data.
    set(himage, 'CData', event.Data)
    end
%% Callbacks for Snapshot
    function snapshot_callback(hObject, eventdata)
    hFig2 = figure('Toolbar','none','Menubar', 'none','NumberTitle','Off',...
    'Name','Snapshot');
    imagesc(getsnapshot(vid));
    %imagesc(ycbcr2rgb(getsnapshot(vid)));
    figure(hFig);
    end
%% Callback for SaveImages
    function saveimages_callback(hObject,eventdata)
    for i=1:100
        figure('Toolbar','none','Menubar', 'none','NumberTitle','Off',...
        'Name','Snapshot','Visible','off');
        imagesc(getsnapshot(vid));
        wait(vid,.001);
        saveas(gca,['ArialPic_' int2str(i)],'jpg') ;
        %if tgl.value==0, break; end;
    end
    figure(hFig);
    end
%% Callbacks for StopPreview
    function stoppreview_callback(hObject, eventdata)
    stoppreview(vid);
    figure(hFig);
    end
%% Callback for StartPreview
    function startpreview_callback(hObject, eventdata)
    figure(hFig);
    preview(vid);    
    end
%% Callback for StartCapture
    function startcapture_callback(hObject, eventdata)
    set(vid,'TriggerFrameDelay',3);
    set(vid,'TriggerRepeat',0);
    set(vid,'Timeout',Inf);
    set(vid,'LoggingMode','disk');
    set(vid,'FramesPerTrigger',1000000);
    aviobj = avifile('UAV_datalog.avi','compression','none', 'fps', 30, 'quality', 50);
    set(vid,'DiskLogger',aviobj);
    start(vid);
    end
%% Callback for StopCapture
    function stopcapture_callback(hObject, eventdata)
    stop(vid);
    aviobj = close(vid.DiskLogger);
        if(exist('UAV_datalog.avi')==2)
        disp('AVI file created.')
        end
    end
%% Callback for deletefig_callback
    function deletefig_callback(hObject,eventdata)
    delete(vid);
    clear vid;
    end
end